( cd usr/lib ; rm -rf libgtksourceview-2.0.so )
( cd usr/lib ; ln -sf libgtksourceview-2.0.so.0.0.0 libgtksourceview-2.0.so )
( cd usr/lib ; rm -rf libgtksourceview-2.0.so.0 )
( cd usr/lib ; ln -sf libgtksourceview-2.0.so.0.0.0 libgtksourceview-2.0.so.0 )
